pub struct ControlInst {
pub attrs: AttrSet,
pub kind: ControlInstKind,
pub inputs: SmallVec<[Value; 2]>,
pub targets: SmallVec<[ControlRegion; 4]>,
pub target_inputs: IndexMap<ControlRegion, SmallVec<[Value; 2]>, BuildHasherDefault<FxHasher>>,
}Fields
attrs: AttrSetkind: ControlInstKindinputs: SmallVec<[Value; 2]>targets: SmallVec<[ControlRegion; 4]>target_inputs: IndexMap<ControlRegion, SmallVec<[Value; 2]>, BuildHasherDefault<FxHasher>>target_inputs[region][input_idx] is the Value that
Value::ControlRegionInput { region, input_idx } will get on entry,
where region must be appear at least once in targets - this is a
separate map instead of being part of targets because it reflects the
limitations of φ (“phi”) nodes, which (unlike “basic block arguments”)
cannot tell apart multiple edges with the same source and destination.