pub enum KhrSegmented {}Expand description
Segmented sparse storage, taking advantage of Khronos’ predictable
reservation policy for SPIR-V instruction opcodes and ValueEnums:
- indices in
0..=4096are reserved for the standard, and mostly allocated without gaps (~84% density at the time of writing) - indices in
4096..are allocated in blocks of64; while sparser than the standard range, the blockiness allows some optimizations