pub struct GlobalVarDecl {
pub attrs: AttrSet,
pub type_of_ptr_to: Type,
pub shape: Option<GlobalVarShape>,
pub addr_space: AddrSpace,
pub def: DeclDef<GlobalVarDefBody>,
}Expand description
Declaration/definition for a GlobalVar: a global variable.
Fields
attrs: AttrSettype_of_ptr_to: TypeThe type of a pointer to the global variable (as opposed to the value type).
shape: Option<GlobalVarShape>When type_of_ptr_to is QPtr, shape must be used to describe the
global variable (see GlobalVarShape’s documentation for more details).
addr_space: AddrSpaceThe address space the global variable will be allocated into.
def: DeclDef<GlobalVarDefBody>Trait Implementations
Sourceimpl Clone for GlobalVarDecl
impl Clone for GlobalVarDecl
Sourcefn clone(&self) -> GlobalVarDecl
fn clone(&self) -> GlobalVarDecl
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl InnerInPlaceTransform for GlobalVarDecl
impl InnerInPlaceTransform for GlobalVarDecl
fn inner_in_place_transform_with(&mut self, transformer: &mut impl Transformer)
Sourceimpl InnerVisit for GlobalVarDecl
impl InnerVisit for GlobalVarDecl
fn inner_visit_with<'a>(&'a self, visitor: &mut impl Visitor<'a>)
Sourceimpl Print for GlobalVarDecl
impl Print for GlobalVarDecl
type Output = AttrsAndDef
fn print(&self, printer: &Printer<'_>) -> AttrsAndDef
Sourceimpl Visit for GlobalVarDecl
impl Visit for GlobalVarDecl
fn visit_with<'a>(&'a self, visitor: &mut impl Visitor<'a>)